duration_to_ts

Function duration_to_ts 

fn duration_to_ts(duration: Duration) -> Timestamp
A millisecond Duration as a Timestamp, saturating at Timestamp::MAX on overflow rather than panicking the controller on a bad input.